<?php 

namespace ADTW;

class SettingsPage {

    protected function __construct() { }

    public static function init() 
    {
        global $adtw_option;
        add_action('admin_menu', [__CLASS__, 'adminMenus'], 99999);

        # ADTW()->debug("Admin Tweaks v".AdminTweaks::VERSION);
        
        add_filter(
            'plugin_action_links_' . ADTW_BASE,
            array( __CLASS__, 'settings_plugin_link' ),
            10, 2
        );
        
        add_filter( 
            'plugin_row_meta', 
            array( __CLASS__, 'donate_link' ), 
            10, 4 
        );

        /* Redux CSS */
        add_action(
            'redux/page/' . $adtw_option . '/enqueue',
            [__CLASS__, 'add_panel_css']
        );

        /* Redux Help Tab */
        add_action(
            'redux/page/' . $adtw_option . '/load',
            [__CLASS__, 'redux_load']
        );
    }
    
    public static function redux_load() 
    {
        get_current_screen()->remove_help_tab('redux-hint-tab');
    }

    public static function adminMenus() 
    {
        ADTW()->setSupport();
    }

    public static function add_panel_css() 
    {
        wp_register_style(
            'redux-custom-css',
            ADTW_URL . '/assets/adtw.css',
            [ 'redux-admin-css' ], 
            ADTW()->cache('/assets/adtw.css'),
            'all'
        );  
        wp_enqueue_style('redux-custom-css');
    }


	/**
	 * Add link to settings in Plugins list page
	 *
	 * @wp-hook plugin_action_links
	 * @return Plugin link
	 */
	public static function settings_plugin_link( $links, $file ) 
    {
        $links[] = sprintf(
            '<a href="%s">%s</a>',
                admin_url( 'admin.php?page=admintweaks' ),
                __( 'Settings' )
        );
		return $links;
	}


    /**
     * Add donate link to plugin description in /wp-admin/plugins.php
     *
     * @param array $plugin_meta
     * @param string $plugin_file
     * @param string $plugin_data
     * @param string $status
     * @return array
     */
    public static function donate_link( $plugin_meta, $plugin_file, $plugin_data, $status ) 
    {
        if( $plugin_file == ADTW_BASE )
            $plugin_meta[] = '&hearts; <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=JNJXKWBYM9JP6&lc=ES&item_name=Admin%20Tweaks%20%3a%20Rodolfo%20Buaiz&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted">Buy me a beer :o)</a>';
		return $plugin_meta;
	}

}