<?php
/**
 * Section Admin Menu config
 * 
 * @package Admin Tweaks
 */

defined( 'ABSPATH' ) || exit;

$url_wpse = ADTW_URL . '/assets/images/adminmenus-bubbles.jpg';
$url_wpse12 = ADTW_URL . '/assets/images/adminmenus-sorting.jpg';
$acf_unique_user = [];

if ( class_exists( 'ACF' )  ):
    $acf_unique_user = [
        'id'               => 'plugins_acf_show_only',
        'type'             => 'select',
        'data'             => 'users',
        'ajax'             => true,
        'min_input_length' => 3,
        'title'            => esc_html__( 'ADVANCED CUSTOM FIELDS', 'mtt' ),
        'subtitle'         => esc_html__( 'show ACF menu only for one user', 'mtt' ),
        'desc'             => esc_html__( 'Select authorized user; leave empty to disable the feature', 'mtt' ),
    ];
endif;

\Redux::set_section(
	$adtw_option,
	array(
		'title' => esc_html__( 'Admin Menu', 'mtt' ),
		'id'    => 'adminmenu',
        'icon' => 'el el-arrow-left',
        'fields' => [
            array( # Remove Items
                'id'       => 'admin_menus_remove',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Remove Menu Items', 'mtt' ),
                'subtitle'     => sprintf(
                    '%s<br><br><i>%s</i>',
                    esc_html__( 'Select items to remove.', 'mtt' ),
                    esc_html__( 'The list of post types needs 2 page refreshes before updating.', 'mtt' )
                ),
                'desc' => sprintf(
                    esc_html__( 'This removes the menus for all users.%1$s It doesn\'t prevent access to the actual url address of the item.%1$s For a better fine tuning use %2$s. To really block the access use a plugin like %3$s or check this %4$s.', 'mtt' ),
                    '<br>',
                    '<a target="_blank" href="http://wordpress.org/extend/plugins/adminimize/">Adminimize</a>',
                    '<a target="_blank" href="http://wordpress.org/extend/plugins/members/">Members</a>',
                    '<a target="_blank" href="http://stackoverflow.com/q/23568456/1287812">Snippet</a>'
                ),
                'multi'    => true,
                'options' => array_values(ADTW()->getMenus()),
            ),
			array( # Rename Posts
				'id'    => 'posts_rename_enable',
				'type'  => 'switch',
				'title' => esc_html__( 'Rename Posts', 'mtt' ),
                'desc'  => esc_html__( 'Change the label of the default Post type instead of creating a new custom post type  called News or Articles.', 'mtt') 
                        . '<br>' 
                        . esc_html__('Tip via:', 'mtt' )
                        . '<a href="http://wordpress.stackexchange.com/a/9224/12615" target="_blank">WordPress Answers</a>',
				'default'  => false,
			),
            array( ## Rename posts to  
				'id'          => 'posts_rename_name',
				'type'        => 'text',
				'title'       => '',
				'desc'    => esc_html__('Rename "Post" to:', 'mtt'),
				'placeholder' => esc_html__('Enter new name', 'mtt'),
				/*'data'        => array( 
                    'name' => esc_html__('Name', 'mtt'),
                    'singular_name' => esc_html__('Singular Name', 'mtt'), 
                    'add_new' => esc_html__('Add New', 'mtt'), 
                    'edit_item' => esc_html__('Edit Posts', 'mtt'), 
                    'view_item' => esc_html__('View Posts', 'mtt'), 
                    'search_items' => esc_html__('Search Posts', 'mtt'), 
                    'not_found' => esc_html__('No Posts found', 'mtt'), 
                    'not_found_in_trash' => esc_html__('No Posts found in trash', 'mtt'), 
                ),*/
				'required' => array( 'posts_rename_enable', '=', true ),
			),
			array( # Status Bubbles
				'id'       => 'admin_menus_bubbles',
				'type'     => 'switch',
				'title'    => esc_html__( 'Post Status Bubbles', 'mtt' ),
                'desc' => sprintf(
                    esc_html__( 'Tip via: %s', 'mtt' ), 
                    '<a href="http://wordpress.stackexchange.com/a/95058/12615" target="_blank">WordPress Answers</a>'
                ),
				'default'  => false,
                'hint'     => array(
					'title'   => '',
					'content' => "<div class='img-help-mini'><img src='$url_wpse' /></div>",
				),
			),
            array( ## Bubbles cpts 
                'id'       => 'admin_menus_bubbles_cpts',
                'type'     => 'button_set',
                'title' => '', 
                'desc'=> 'Show bubles on the following post types',
                'multi'    => true,
                'options' => ADTW()->getCPTs(),
				'required' => array( 'admin_menus_bubbles', '=', true ),
            ),
            array( ## Bubbles status 
                'id'       => 'admin_menus_bubbles_status',
                'type'     => 'button_set',
                'title' => '', 
                'desc'=> 'Show bubles on the following status',
                'multi'    => false,
                'options' => ADTW()->getStatus(),
                'default' => 'none',
				'required' => array( 'admin_menus_bubbles', '=', true ),
            ),
			array( # Sort Settings
				'id'       => 'admin_menus_sort_wordpress',
				'type'     => 'switch',
				'title'    => esc_html__( 'Sort Settings', 'mtt' ),
				'desc'    => esc_html__( 'sort items in Settings menu [A-Z]', 'mtt' ),
				'default'  => false,
                'hint'     => array(
					'title'   => '',
					'content' => "<div class='img-help-small'><img src='$url_wpse12' /></div>",
				),
			),
			array( # Sort Settings by Plugins
				'id'       => 'admin_menus_sort_plugins',
				'type'     => 'switch',
				'title'    => esc_html__( 'Sort Settings by Plugins', 'mtt' ),
				'desc'    => esc_html__( 'Plugins submenu items and WordPress submenu items are shown separated, see screenshot above', 'mtt' ),
				'default'  => false
			),
            # # # ## Advanced Custom Fields
            $acf_unique_user, 

        ]
	)
);